# Generated by Django 3.0.8 on 2020-07-17 15:09

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('lifecycles', '0002_auto_20200717_1506'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lifecycle',
            name='date',
            field=models.DateField(default=django.utils.timezone.now),
        ),
    ]
