# Generated by Django 3.0.8 on 2020-07-17 15:06

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lifecycles', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lifecycle',
            name='date',
            field=models.DateField(default=datetime.datetime(2020, 7, 17, 15, 6, 12, 223023)),
        ),
        migrations.AlterField(
            model_name='lifecycleactiontype',
            name='name',
            field=models.DateField(),
        ),
    ]
