# Generated by Django 3.0.8 on 2020-07-22 12:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lifecycles', '0005_auto_20200722_1212'),
    ]

    operations = [
        migrations.AddField(
            model_name='lifecycle',
            name='created',
            field=models.DateField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='lifecycle',
            name='last_updated',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
    ]
