# Generated by Django 3.0.8 on 2020-07-16 11:13

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('dcim', '0106_role_default_color'),
        ('tenancy', '0009_standardize_description'),
    ]

    operations = [
        migrations.CreateModel(
            name='LifecycleActionType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False)),
                ('name', models.DateField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Lifecycle',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False)),
                ('date', models.DateField(blank=True, null=True)),
                ('action_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='lifecycles.LifecycleActionType')),
                ('device', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='dcim.Device')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='tenancy.Tenant')),
            ],
        ),
    ]
