# Generated by Django 3.0.8 on 2020-07-17 16:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lifecycles', '0003_auto_20200717_1509'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lifecycleactiontype',
            name='name',
            field=models.CharField(max_length=50),
        ),
    ]
