# Generated by Django 3.0.8 on 2020-07-22 16:13

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('tenancy', '0009_standardize_description'),
        ('dcim', '0106_role_default_color'),
        ('lifecycles', '0006_auto_20200722_1253'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='lifecycle',
            options={'ordering': ['id']},
        ),
        migrations.AlterField(
            model_name='lifecycle',
            name='action_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='lifecycles.LifecycleActionType'),
        ),
        migrations.AlterField(
            model_name='lifecycle',
            name='device',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='dcim.Device'),
        ),
        migrations.AlterField(
            model_name='lifecycle',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tenancy.Tenant'),
        ),
    ]
