# Generated by Django 3.0.8 on 2020-07-22 12:12

from django.db import migrations, models
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ('extras', '0042_customfield_manager'),
        ('lifecycles', '0004_auto_20200717_1625'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='lifecycle',
            options={'ordering': ['device', 'date', 'action_type']},
        ),
        migrations.AddField(
            model_name='lifecycle',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='lifecycle',
            name='tags',
            field=taggit.managers.TaggableManager(through='extras.TaggedItem', to='extras.Tag'),
        ),
    ]
