{% extends 'base.html' %}
{% load buttons %}

{% block content %}
    <div class="pull-right noprint">
        {% if perms.lifecycles.add_lifecycleactiontype %}
            {% add_button 'plugins:lifecycles:lifecycle_action_type_add' %}
        {% endif %}
    </div>
    <h1>{% block title %}Lifecycle Action Types{% endblock %}</h1>
    <div class="row">
        <div class="col-md-9">
            {% include 'utilities/obj_table.html' with bulk_delete_url='plugins:lifecycles:lifecycle_action_type_bulk_delete' %}
        </div>
        <div class="col-md-3 noprint">
            {% include 'inc/search_panel.html' %}
        </div>
    </div>
{% endblock %}
