from setuptools import find_packages, setup

setup(
    name='netbox-plugin-lifecycles',
    version='1.0.4',
    description='Lifecycles for devices',
    url='https://git.selectel.org/ogorov/netbox-lifecycles.git',
    author='DCIM',
    license='Apache 2.0',
    install_requires=[],
    packages=find_packages(),
    include_package_data=True,
)
